==> haskell-ansi-terminal-0.11-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11
visibility:           public
id:                   ansi-terminal-0.11-KZlfwqvn41oLlRmR1M9CEn
key:                  ansi-terminal-0.11-KZlfwqvn41oLlRmR1M9CEn
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/feuerbach/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  1137a521b9a51a552d0f58a95e2d7047
exposed:              True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ansi-terminal-0.11
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ansi-terminal-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/ansi-terminal-0.11
hs-libraries:         HSansi-terminal-0.11-KZlfwqvn41oLlRmR1M9CEn
depends:              base-4.14.2.0 colour-2.3.5-6IgISjVABr17DDXvEVpmLi
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-0.11-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11
visibility:           public
id:                   ansi-terminal-0.11-BBkFrpcwU1I4YIp6efj9lt
key:                  ansi-terminal-0.11-BBkFrpcwU1I4YIp6efj9lt
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/feuerbach/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  3b70d632d377ce7f7deeb199ce8116d8
exposed:              True
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/ansi-terminal-0.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/ansi-terminal-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/ansi-terminal-0.11
hs-libraries:         HSansi-terminal-0.11-BBkFrpcwU1I4YIp6efj9lt
depends:              base-4.15.0.0 colour-2.3.5-408TcGs5I9SCembFk0PxU3
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
